@define-color boxes_bg_color shade (@theme_bg_color, 0.5);
@define-color boxes_bg2_color mix (@theme_bg_color, @boxes_bg_color, 0.5);
@define-color boxes_selected_color #3465a4;

.boxes-snapshot-list-row {
    border-bottom: 1px solid @borders;
}

.boxes-snapshot-list-row.indicator {
    background-color: @insensitive_fg_color;
    border: none;
}

.boxes-snapshot-list-row.indicator.active {
    background-color: @theme_fg_color;
}

BoxesResourceGraph {
    background-color: @boxes_bg_color;
    border-color: @theme_fg_color;
    color: @theme_bg_color;
}

.transparent-bg {
    background-color: transparent;
    background-image: none;
}

.content-bg {
    background-color: @content_view_bg;
}

.boxes-toplevel {
    background-color: @theme_bg_color;
}

.slow-spinner {
    animation-duration: 2s;
}

/******************
 * New Box Wizard *
 ******************/

/* This is the subtitle in the ISOs/media list */
.boxes-step-label {
    font-size: smaller;
    font-weight: normal;
}

.boxes-wizard-media-os-label {
    color: #d8d8d8;
    font-weight: bold;
}

.boxes-logo-notice-label {
    font-size: smaller;
    font-style: italic;
}

.boxes-product-key-entry {
    font-family: monospace;
}

/* Ensure the viewport is transparent so the background don't
   show through the rounded corners */
.boxes-menu GtkViewport {
    background-image: none;
    background-color: transparent;
    border-style: none;
}

/* Corner rounding */
.boxes-menu >.boxes-menu-row:nth-last-child(2) {
    border-radius: 0 0 15px 15px;
    outline-radius: 0 0 13px 13px;
}

.boxes-menu > .boxes-menu-row:last-child {
    border-radius: 0 0 15px 15px;
}

.label + .boxes-menu-row,
.boxes-menu-row.button:first-child {
    border-radius: 15px 15px 0 0;
    border-top-style: none;
    outline-radius: 13px 13px 0 0;
}

/* Row styling */
.boxes-menu-row {
    border-style: solid none none none;
    border-width: 1px;
    border-radius: 0;
    border-color: transparent;
    background-color: @boxes_bg2_color;
    background-clip: padding-box;
}

.boxes-menu-row.button {
    background-image: none;
    font-weight: bold;
    text-shadow: none;
    icon-shadow: none;
    box-shadow: none;
    outline-color: alpha(currentColor, 0.15);
}

.boxes-menu-row:hover {
    background-color: @theme_bg_color;
}

.boxes-menu-row:active {
    color: @theme_selected_fg_color;
    background-color: @theme_selected_bg_color;
}

/* Adds a border to the ISOs lists top undershoot */
.boxes-menu-scrolled.undershoot.top { border-top: 1px solid @borders; }
